prep_submission: Prepare pre-filled fields in the submission form
prep_submission generate some answers based on the .tex file to fill
the article submission form. You can save the answers if assigned it to an
object.
Description
Prepare pre-filled fields in the submission form
prep_submission generate some answers based on the .tex file to fill
the article submission form. You can save the answers if assigned it to an
object.