Learn R Programming

rjtools (version 1.0.18.1)

zip_paper: Zip your directory for R Journal submission

Description

zip_paper will first check the folder structure with [rjtools::check_folder_structure()] before zipping up everything in the main directory, excluding the `.Rproj` file, if exist.

Usage

zip_paper()

Arguments

Value

a zip file for an R Journal submission