The R Journal is built upon the distill framework with some modifications. This output format behaves almost identically to the `distill::distill_article()` format, with some formatting and structural changes. The `rjournal_article()` format will produce both HTML and PDF outputs, while the `rjournal_pdf_article()` produces only the PDF output.
rjournal_article(toc = FALSE, self_contained = FALSE, ...)rjournal_pdf_article(..., self_contained = FALSE, citation_package = "natbib")
rjournal_web_article(toc = FALSE, self_contained = FALSE, ...)
the rendered R Journal article
TRUE to include a table of contents in the output
Produce a standalone HTML file with no external dependencies, using data: URIs to incorporate the contents of linked scripts, stylesheets, images, and videos. Note that even for self contained documents MathJax is still loaded externally (this is necessary because of its size).
Arguments passed to `distill::distill_article()` for web articles, and `rticles::rjournal_article()` for pdf articles.
The LaTeX package to process citations, natbib
or biblatex. Use default if neither package is to be used,
which means citations will be processed via the command
pandoc-citeproc.