powered by
zip_paper will first check the folder structure with [rjtools::check_folder_structure()] before zipping up everything in the main directory, excluding the `.Rproj` file, if exist.
zip_paper
zip_paper()
a zip file for an R Journal submission